PostHogSessionReplayConfig class

Configuration for mobile session replay capture and masking.

Assign an instance to PostHogConfig.sessionReplayConfig before calling Posthog().setup(config).

Constructors

PostHogSessionReplayConfig()
Creates a session replay configuration with default masking enabled.

Properties

debouncerDelay Duration
Deprecated setter that forwards assigned values to throttleDelay.
no getter
hashCode int
The hash code for this object.
no setterinherited
maskAllImages bool
Enable masking of all images. Default: true.
getter/setter pair
maskAllTexts bool
Enable masking of all text and text input fields. Default: true.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate double?
Session replay sample rate between 0 and 1. Local config has precedence over remote config when both are set. If null, sampling is controlled by remote config (when available).
getter/setter pair
throttleDelay Duration
Throttling delay used to reduce the number of snapshots captured and reduce performance impact.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this session replay configuration to a platform-channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited